'use strict';
var through = require('through2');
var gutil = require('gulp-util');
var path = require('path');

module.exports = function (opts) {
    var pluginName = 'gulp-openui5-preload';
    var preloadObject;
    var firstFile;
    var prefix;

    opts = opts || {};
    prefix = (opts.prefix) ? opts.prefix + '/' : '';

    preloadObject = {
        version: '2.0',
        name: prefix + 'Component-preload',
        modules: {}
    };

    function bufferContents(file, enc, cb) {
        var filePath;

        if (file.isStream()) {
            this.emit('error', new gutil.PluginError(pluginName, 'Streaming not supported'));
            cb();
            return;
        }

        if (!firstFile) {
            firstFile = file;
        }

        filePath = prefix + file.relative.replace(/\\/g, '/');
        preloadObject.modules[filePath] = String(file.contents);
        cb();
    }

    function endStream(cb) {
        if (!firstFile) {
            cb();
            return;
        }

        var content = 'jQuery.sap.registerPreloadedModules(' + JSON.stringify(preloadObject, null, '\t') + ');';

        // Output File
        this.push(new gutil.File({
            cwd: firstFile.cwd,
            base: firstFile.base,
            path: path.join(firstFile.base, '/Component-preload.js'),
            contents: new Buffer(content)
        }));
        cb();
    }

    return through.obj(bufferContents, endStream);
};